@@ -1,6 +1,7 @@
 /*
-    SPDX-FileCopyrightText: 2004 Ace Jones <Ace Jones <acejones@users.sourceforge.net>>
-    SPDX-FileCopyrightText: 2017 Łukasz Wojniłowicz <Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>>
+    SPDX-FileCopyrightText: 2004 Ace Jones <acejones@users.sourceforge.net>
+    SPDX-FileCopyrightText: 2017 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-FileCopyrightText: 2021 Dawid Wróbel <me@dawidwrobel.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -270,15 +271,47 @@ bool WebPriceQuote::launchNative(const QString& _webID, const QString& _kmmID, c
         QString program;
         QStringList arguments = url.toLocalFile().split(' ', QString::SkipEmptyParts);
         if (!arguments.isEmpty()) {
-#ifndef IS_APPIMAGE
             program = arguments.first();
             arguments.removeFirst();
-#else
-            program = QStringLiteral("/bin/sh");
-            arguments.clear();
-            arguments << QStringLiteral("-c");
-            arguments << url.toLocalFile();
-#endif
+
+            // in case we are running as AppImage, we need
+            // to prepend "/bin/sh -c " here
+            if (qEnvironmentVariableIsSet("APPDIR")) {
+                program = QStringLiteral("/bin/sh");
+                arguments.clear();
+                arguments << QStringLiteral("-c");
+                arguments << url.toLocalFile();
+
+                /*
+                 * Adjust the LD_LIBRARY_PATH environment variable to exclude
+                 * the AppImage mount point so that external tools do not try
+                 * to use libs contained inside the AppImage
+                 */
+                auto environment = QProcessEnvironment::systemEnvironment();
+                auto ld_library_path = environment.value(QLatin1String("LD_LIBRARY_PATH"));
+                qDebug() << "WebPriceQuote::launchNative";
+                qDebug() << "LD_LIBRARY_PATH" << ld_library_path;
+                if (!ld_library_path.isEmpty()) {
+                    const auto appdir = environment.value(QLatin1String("APPDIR"));
+                    qDebug() << "APPDIR" << appdir;
+                    auto path_list = ld_library_path.split(QLatin1Char(':'));
+                    while (!path_list.isEmpty() && path_list.at(0).startsWith(appdir)) {
+                        path_list.removeAt(0);
+                        ld_library_path.clear();
+                        if (!path_list.isEmpty()) {
+                            ld_library_path = path_list.join(QLatin1Char(':'));
+                        }
+                        if (!ld_library_path.isEmpty()) {
+                            environment.insert(QLatin1String("LD_LIBRARY_PATH"), ld_library_path);
+                            qDebug() << "LD_LIBRARY_PATH" << ld_library_path;
+                        } else {
+                            environment.remove(QLatin1String("LD_LIBRARY_PATH"));
+                            qDebug() << "LD_LIBRARY_PATH removed";
+                        }
+                        d->m_filter.setProcessEnvironment(environment);
+                    }
+                }
+            }
         }
         d->m_filter.setWebID(d->m_webID);
 
@@ -678,6 +711,16 @@ const QMap<QString, WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources()
                              "%y %m %d"                   // date format
                                                 );
 
+    result["Puls Biznesu - Funds"] = WebPriceQuoteSource("Puls Biznesu - Funds",
+                                                         "http://notowania.pb.pl/instrument/%1",
+                                                         QString(),
+                                                         QString(), // webIDRegExp
+                                                         WebPriceQuoteSource::identifyBy::IdentificationNumber,
+                                                         "(\\d+,\\d{2})\\D+\\(\\d{4}-\\d{2}-\\d{2}\\)", // price regexp
+                                                         "\\d+,\\d{2}\\D+\\((\\d{4}-\\d{2}-\\d{2})\\)", // date regexp
+                                                         "%y-%m-%d" // date format
+    );
+
     // The following price quote was contributed by
     // Piotr Adacha <piotr.adacha@googlemail.com>
 
@@ -767,6 +810,8 @@ const QStringList WebPriceQuote::quoteSourcesNative()
     QRegularExpressionMatch match;
 
     // get rid of all 'non online quote source' entries
+    // and only keep the names of the quote sources in the list
+    // (i.e. remove the leading "Online-Quote-Source-")
     for (it = groups.begin(); it != groups.end(); it = groups.erase(it)) {
         if ((*it).indexOf(onlineQuoteSource, 0, &match) >= 0) {
             // Insert the name part
@@ -798,7 +843,7 @@ const QStringList WebPriceQuote::quoteSourcesNative()
 
     // if the user has OLD quote source based only on symbols (and not ISIN)
     // now is the time to convert it to the new system.
-    foreach (const auto group, groups) {
+    for (const auto& group : groups) {
         KConfigGroup grp = kconfig->group(QString(QLatin1String("Online-Quote-Source-%1")).arg(group));
         if (grp.hasKey("SymbolRegex")) {
             grp.writeEntry("IDRegex", grp.readEntry("SymbolRegex"));
@@ -889,6 +934,7 @@ void WebPriceQuoteSource::write() const
     else
         grp.deleteEntry("SkipStripping");
     kconfig->sync();
+    kconfig->reparseConfiguration();
 }
 
 void WebPriceQuoteSource::rename(const QString& name)
@@ -903,6 +949,7 @@ void WebPriceQuoteSource::remove() const
     KSharedConfigPtr kconfig = KSharedConfig::openConfig();
     kconfig->deleteGroup(QString("Online-Quote-Source-%1").arg(m_name));
     kconfig->sync();
+    kconfig->reparseConfiguration();
 }
 
 //
