@@ -29,13 +29,13 @@ class KAvailableCurrencyDlg : public QDialog
 {
     Q_OBJECT
 public:
-    explicit KAvailableCurrencyDlg(QWidget *parent = nullptr);
+    explicit KAvailableCurrencyDlg(const QList<QString>& usedCurrencies, QWidget* parent = nullptr);
     ~KAvailableCurrencyDlg();
 
     QList<QTreeWidgetItem *> selectedItems() const;
 
 protected Q_SLOTS:
-    void slotLoadCurrencies();
+    void slotLoadCurrencies(const QList<QString>& usedCurrencies);
     void slotItemSelectionChanged();
 
 private:
