@@ -182,9 +182,8 @@ public:
     {
         auto remain = m_schedule.transactionsRemaining();
         if (remain != ui->m_RemainingEdit->value()) {
-            ui->m_RemainingEdit->blockSignals(true);
+            QSignalBlocker blocker(ui->m_RemainingEdit);
             ui->m_RemainingEdit->setValue(remain);
-            ui->m_RemainingEdit->blockSignals(false);
         }
     }
 
@@ -313,17 +312,6 @@ TransactionEditor* KEditScheduleDlg::startEdit()
         }
         editor->setup(d->m_tabOrderWidgets, d->m_schedule.account(), action);
 
-        // if it's not a check, then we need to clear
-        // a possibly assigned check number
-        if (d->m_schedule.paymentType() != Schedule::PaymentType::WriteChecque) {
-            QWidget* w = editor->haveWidget("number");
-            if (w) {
-                if (auto numberWidget = dynamic_cast<KMyMoneyLineEdit*>(w)) {
-                    numberWidget->loadText(QString());
-                }
-            }
-        }
-
         Q_ASSERT(!d->m_tabOrderWidgets.isEmpty());
 
         d->m_tabOrderWidgets.push_front(d->ui->m_paymentMethodEdit);
@@ -366,8 +354,12 @@ TransactionEditor* KEditScheduleDlg::startEdit()
         }
 
         // connect the postdate modification signal to our update routine
-        if (auto dateEdit = dynamic_cast<KMyMoneyDateInput*>(editor->haveWidget("postdate")))
+        if (auto dateEdit = dynamic_cast<KMyMoneyDateInput*>(editor->haveWidget("postdate"))) {
             connect(dateEdit, &KMyMoneyDateInput::dateChanged, this, &KEditScheduleDlg::slotPostDateChanged);
+            connect(d->ui->m_lastDayInMonthEdit, &QCheckBox::stateChanged, dateEdit, &KMyMoneyDateInput::setDisabled);
+            // update initial state
+            dateEdit->setDisabled(d->ui->m_lastDayInMonthEdit->isChecked());
+        }
 
         d->ui->m_nameEdit->setFocus();
 
@@ -381,9 +373,6 @@ TransactionEditor* KEditScheduleDlg::startEdit()
             label->setText(i18n("Next due date"));
 
         d->m_editor = editor;
-        slotSetPaymentMethod((int)d->m_schedule.paymentType());
-
-        connect(d->ui->m_paymentMethodEdit, &KMyMoneyGeneralCombo::itemSelected, this, &KEditScheduleDlg::slotSetPaymentMethod);
         connect(editor, &TransactionEditor::operationTypeChanged, this, &KEditScheduleDlg::slotFilterPaymentType);
     }
 
@@ -640,11 +629,8 @@ void KEditScheduleDlg::slotRemainingChanged(int value)
     d->m_schedule.setOccurrencePeriod(static_cast<Schedule::Occurrence>(d->ui->m_frequencyEdit->currentItem()));
     d->m_schedule.setOccurrenceMultiplier(d->ui->m_frequencyNoEdit->value());
 
-    if (d->m_schedule.transactionsRemaining() != value) {
-        d->ui->m_FinalPaymentEdit->blockSignals(true);
-        d->ui->m_FinalPaymentEdit->setDate(d->m_schedule.dateAfter(value));
-        d->ui->m_FinalPaymentEdit->blockSignals(false);
-    }
+    QSignalBlocker blocker(d->ui->m_FinalPaymentEdit);
+    d->ui->m_FinalPaymentEdit->setDate(d->m_schedule.dateAfter(value));
 }
 
 void KEditScheduleDlg::slotEndDateChanged(const QDate& date)
@@ -656,10 +642,8 @@ void KEditScheduleDlg::slotEndDateChanged(const QDate& date)
     d->m_schedule.setOccurrencePeriod(static_cast<Schedule::Occurrence>(d->ui->m_frequencyEdit->currentItem()));
     d->m_schedule.setOccurrenceMultiplier(d->ui->m_frequencyNoEdit->value());
 
-    if (d->m_schedule.endDate() != date) {
-        d->m_schedule.setEndDate(date);
-        d->updateTransactionsRemaining();
-    }
+    d->m_schedule.setEndDate(date);
+    d->updateTransactionsRemaining();
 }
 
 void KEditScheduleDlg::slotPostDateChanged(const QDate& date)
@@ -677,20 +661,6 @@ void KEditScheduleDlg::slotPostDateChanged(const QDate& date)
     }
 }
 
-void KEditScheduleDlg::slotSetPaymentMethod(int item)
-{
-    Q_D(KEditScheduleDlg);
-    const bool isWriteCheck = item == (int)Schedule::PaymentType::WriteChecque;
-    if (auto numberEdit = dynamic_cast<KMyMoneyLineEdit*>(d->m_editor->haveWidget("number"))) {
-        numberEdit->setVisible(isWriteCheck);
-
-        // hiding the label does not work, because the label underneath will shine
-        // through. So we either write the label or a blank
-        if (auto label = dynamic_cast<QLabel *>(d->m_editor->haveWidget("number-label")))
-            label->setText(isWriteCheck ? i18n("Number") : QStringLiteral(" "));
-    }
-}
-
 void KEditScheduleDlg::slotFrequencyChanged(int item)
 {
     Q_D(KEditScheduleDlg);
