@@ -295,7 +295,7 @@ bool TransactionEditor::eventFilter(QObject* o, QEvent* e)
                     if (widget && widget->splitButton())
                         QApplication::sendEvent(o, &evt);
 
-                } else {
+                } else if (!d->m_readOnly) {
                     QTimer::singleShot(0, this, SIGNAL(returnPressed()));
                 }
                 // don't process any further
@@ -843,3 +843,9 @@ void TransactionEditor::slotNewInvestment(MyMoneyAccount& account, const MyMoney
 {
     KNewInvestmentWizard::newInvestment(account, parent);
 }
+
+void TransactionEditor::setReadOnlyMode(bool readOnly)
+{
+    Q_D(TransactionEditor);
+    d->m_readOnly = readOnly;
+}
