@@ -33,13 +33,14 @@
 // KDE Headers
 
 #include <KColorScheme>
-#include <KLocalizedString>
 #include <KGuiItem>
-#include <KXmlGuiWindow>
-#include <KMessageBox>
-#include <KStandardGuiItem>
 #include <KIO/StatJob>
 #include <KIO/StoredTransferJob>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KStandardGuiItem>
+#include <KXmlGuiWindow>
+#include <kio_version.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -617,8 +618,12 @@ bool KMyMoneyUtils::fileExists(const QUrl &url)
             fileExists = check_file.exists() && check_file.isFile();
 
         } else {
+#if KIO_VERSION < QT_VERSION_CHECK(5, 70, 0)
             short int detailLevel = 0; // Lowest level: file/dir/symlink/none
             KIO::StatJob* statjob = KIO::stat(url, KIO::StatJob::SourceSide, detailLevel);
+#else
+            auto statjob = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatNoDetails);
+#endif
             bool noerror = statjob->exec();
             if (noerror) {
                 // We want a file
@@ -688,6 +693,7 @@ bool KMyMoneyUtils::newPayee(const QString& newnameBase, QString& id)
 
             MyMoneyPayee p;
             p.setName(newname);
+            p.setMatchData(eMyMoney::Payee::MatchType::NameExact, true, QStringList());
             MyMoneyFile::instance()->addPayee(p);
             id = p.id();
             ft.commit();
