@@ -238,10 +238,9 @@ bool MyMoneyAccount::operator == (const MyMoneyAccount& right) const
     // clang-format on
 }
 
-Account::Type MyMoneyAccount::accountGroup() const
+Account::Type MyMoneyAccount::accountGroup(Account::Type type)
 {
-    Q_D(const MyMoneyAccount);
-    switch (d->m_accountType) {
+    switch (type) {
     case Account::Type::Checkings:
     case Account::Type::Savings:
     case Account::Type::Cash:
@@ -258,10 +257,16 @@ Account::Type MyMoneyAccount::accountGroup() const
         return Account::Type::Liability;
 
     default:
-        return d->m_accountType;
+        return type;
     }
 }
 
+Account::Type MyMoneyAccount::accountGroup() const
+{
+    Q_D(const MyMoneyAccount);
+    return accountGroup(d->m_accountType);
+}
+
 QString MyMoneyAccount::currencyId() const
 {
     Q_D(const MyMoneyAccount);
@@ -416,23 +421,6 @@ MyMoneyMoney MyMoneyAccount::balance() const
     return d->m_balance;
 }
 
-void MyMoneyAccount::adjustBalance(const MyMoneySplit& s, bool reverse)
-{
-    Q_D(MyMoneyAccount);
-    if (s.action() == MyMoneySplit::actionName(eMyMoney::Split::Action::SplitShares)) {
-        if (reverse)
-            d->m_balance = d->m_balance / s.shares();
-        else
-            d->m_balance = d->m_balance * s.shares();
-    } else {
-        if (reverse)
-            d->m_balance -= s.shares();
-        else
-            d->m_balance += s.shares();
-    }
-
-}
-
 void MyMoneyAccount::setBalance(const MyMoneyMoney& val)
 {
     Q_D(MyMoneyAccount);
@@ -441,22 +429,20 @@ void MyMoneyAccount::setBalance(const MyMoneyMoney& val)
 
 QPixmap MyMoneyAccount::accountPixmap(const bool reconcileFlag, const int size) const
 {
-    static const QHash<Account::Type, Icon> accToIco {
-        {Account::Type::Asset, Icon::Asset},
-        {Account::Type::Investment, Icon::Stock},
-        {Account::Type::Stock, Icon::Stock},
-        {Account::Type::MoneyMarket, Icon::Stock},
-        {Account::Type::Checkings, Icon::Checking},
-        {Account::Type::Savings, Icon::Savings},
-        {Account::Type::AssetLoan, Icon::LoanAsset},
-        {Account::Type::Loan, Icon::Loan},
-        {Account::Type::CreditCard, Icon::CreditCard},
-        {Account::Type::Asset, Icon::Asset},
-        {Account::Type::Cash, Icon::Cash},
-        {Account::Type::Income, Icon::Income},
-        {Account::Type::Expense, Icon::Expense},
-        {Account::Type::Equity, Icon::Equity}
-    };
+    static const QHash<Account::Type, Icon> accToIco{{Account::Type::Asset, Icon::Asset},
+                                                     {Account::Type::Investment, Icon::Investment},
+                                                     {Account::Type::Stock, Icon::Stock},
+                                                     {Account::Type::MoneyMarket, Icon::Stock},
+                                                     {Account::Type::Checkings, Icon::Checking},
+                                                     {Account::Type::Savings, Icon::Savings},
+                                                     {Account::Type::AssetLoan, Icon::LoanAsset},
+                                                     {Account::Type::Loan, Icon::Loan},
+                                                     {Account::Type::CreditCard, Icon::CreditCard},
+                                                     {Account::Type::Asset, Icon::Asset},
+                                                     {Account::Type::Cash, Icon::Cash},
+                                                     {Account::Type::Income, Icon::Income},
+                                                     {Account::Type::Expense, Icon::Expense},
+                                                     {Account::Type::Equity, Icon::Equity}};
 
     Icon ixIcon = accToIco.value(accountType(), Icon::Liability);
 
@@ -622,3 +608,8 @@ QString MyMoneyAccount::stdAccName(eMyMoney::Account::Standard stdAccID)
     };
     return stdAccNames.value(stdAccID);
 }
+
+QString MyMoneyAccount::accountSeparator()
+{
+    return QStringLiteral(":");
+}
