@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2014-2015 Cristian One ț <onet.cristian@gmail.com>
+    SPDX-FileCopyrightText: 2014-2015 Cristian Oneț <onet.cristian@gmail.com>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -8,11 +8,20 @@
 #include "mymoneycontact.h"
 
 #ifdef ENABLE_ADDRESSBOOK
-#include <KIdentityManagement/IdentityManager>
 #include <KIdentityManagement/Identity>
+#include <KIdentityManagement/IdentityManager>
+#include <akonadi_version.h>
+
+#if AKONADI_VERSION >= QT_VERSION_CHECK(5, 18, 41)
+#include <Akonadi/Collection>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/RecursiveItemFetchJob>
+#else
 #include <AkonadiCore/RecursiveItemFetchJob>
 #include <AkonadiCore/ItemFetchScope>
 #include <AkonadiCore/Collection>
+#endif
+
 #include <KContacts/Addressee>
 #include <QRegularExpression>
 #endif
