@@ -54,6 +54,7 @@ typedef QMap<QDate, MyMoneyPrice> MyMoneyPriceEntries;
 typedef QMap<MyMoneySecurityPair, MyMoneyPriceEntries> MyMoneyPriceList;
 
 namespace eMyMoney {
+enum class StockSplitDirection;
 namespace Schedule {
 enum class Type;
 }
@@ -1042,6 +1043,8 @@ public:
       */
     void rebuildAccountBalances();
 
+    MyMoneyMoney stockSplit(const QString& accountId, MyMoneyMoney balance, MyMoneyMoney factor, eMyMoney::StockSplitDirection direction) const;
+
     void startTransaction();
     bool commitTransaction();
     void rollbackTransaction();
