@@ -10,26 +10,26 @@
 // ----------------------------------------------------------------------------
 // QT Includes
 
-#include <QUrl>
-#ifdef IS_APPIMAGE
 #include <QCoreApplication>
 #include <QStandardPaths>
-#endif
+#include <QUrl>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <KPluginFactory>
 #include <KActionCollection>
+#include <KIO/StatJob>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KIO/StatJob>
+#include <KPluginFactory>
+#include <kio_version.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
 
 #include "csvexportdlg.h"
 #include "csvwriter.h"
+#include "mymoneyutils.h"
 #include "viewinterface.h"
 
 CSVExporter::CSVExporter(QObject *parent, const QVariantList &args)
@@ -41,15 +41,16 @@ CSVExporter::CSVExporter(QObject *parent, const QVariantList &args)
     const auto rcFileName = QLatin1String("csvexporter.rc");
     setComponentName(componentName, i18n("CSV exporter"));
 
-#ifdef IS_APPIMAGE
-    const QString rcFilePath = QString("%1/../share/kxmlgui5/%2/%3").arg(QCoreApplication::applicationDirPath(), componentName, rcFileName);
-    setXMLFile(rcFilePath);
+    if (MyMoneyUtils::isRunningAsAppImage()) {
+        const QString rcFilePath = QString("%1/../share/kxmlgui5/%2/%3").arg(QCoreApplication::applicationDirPath(), componentName, rcFileName);
+        setXMLFile(rcFilePath);
 
-    const QString localRcFilePath = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).first() + QLatin1Char('/') + componentName + QLatin1Char('/') + rcFileName;
-    setLocalXMLFile(localRcFilePath);
-#else
-    setXMLFile(rcFileName);
-#endif
+        const QString localRcFilePath =
+            QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).first() + QLatin1Char('/') + componentName + QLatin1Char('/') + rcFileName;
+        setLocalXMLFile(localRcFilePath);
+    } else {
+        setXMLFile(rcFileName);
+    }
 
     createActions();
     // For information, announce that we have been loaded.
@@ -97,8 +98,12 @@ bool CSVExporter::okToWriteFile(const QUrl &url)
     bool fileExists = false;
 
     if (url.isValid()) {
+#if KIO_VERSION < QT_VERSION_CHECK(5, 70, 0)
         short int detailLevel = 0; // Lowest level: file/dir/symlink/none
         KIO::StatJob* statjob = KIO::stat(url, KIO::StatJob::SourceSide, detailLevel);
+#else
+        auto statjob = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatNoDetails);
+#endif
         bool noerror = statjob->exec();
         if (noerror) {
             // We want a file
