@@ -1,20 +1,8 @@
 /*
- * Copyright 2018       Martin Preuss <martin@libchipcard.de>
- * Copyright 2004-2019  Thomas Baumgart <tbaumgart@kde.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2018 Martin Preuss <martin@libchipcard.de>
+    SPDX-FileCopyrightText: 2004-2019 Thomas Baumgart <tbaumgart@kde.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 /** @file
  * @short A C++ wrapper of the main aqbanking interface
@@ -94,19 +82,6 @@ public:
 
   int getUserDataDir(GWEN_BUFFER *buf) const ;
 
-  int loadSharedConfig(const char *name, GWEN_DB_NODE **pDb);
-  int saveSharedConfig(const char *name, GWEN_DB_NODE *db);
-  int lockSharedConfig(const char *name);
-  int unlockSharedConfig(const char *name);
-
-  int loadSharedSubConfig(const char *name,
-                         const char *subGroup,
-                         GWEN_DB_NODE **pDb);
-
-  int saveSharedSubConfig(const char *name,
-                         const char *subGroup,
-                         GWEN_DB_NODE *dbSrc);
-
   void setAccountAlias(AB_ACCOUNT_SPEC *a, const char *alias);
 
   /**
