@@ -18,9 +18,10 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <KLocalizedString>
-#include <KLed>
 #include <KComboBox>
+#include <KLed>
+#include <KLocalizedString>
+#include <KProtocolManager>
 #include <KWallet>
 
 // ----------------------------------------------------------------------------
@@ -63,6 +64,7 @@ KOnlineBankingStatus::KOnlineBankingStatus(const MyMoneyAccount& acc, QWidget *p
     m_appId = new OfxAppVersion(m_applicationCombo, m_applicationEdit, settings.value("appId"));
     m_headerVersion = new OfxHeaderVersion(m_headerVersionCombo, settings.value("kmmofx-headerVersion"));
     m_clientUidEdit->setText(settings.value("clientUid"));
+
 #ifndef LIBOFX_HAVE_CLIENTUID
     // in case the installed libofx does not support clientuid
     // we disable the widget
@@ -70,7 +72,9 @@ KOnlineBankingStatus::KOnlineBankingStatus(const MyMoneyAccount& acc, QWidget *p
     m_clientUidLabel->setEnabled(false);
 #endif
 
-    connect(m_applicationCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(applicationSelectionChanged()));
+    m_userAgentEdit->setPlaceholderText(KProtocolManager::defaultUserAgent());
+    m_userAgentEdit->setText(settings.value(QLatin1String("kmmofx-useragent")));
+    connect(m_applicationCombo, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &KOnlineBankingStatus::applicationSelectionChanged);
     m_headerVersionEdit->hide();
 
     int numDays = 60;
