@@ -13,12 +13,16 @@
 // ----------------------------------------------------------------------------
 // QT Includes
 
-#include <QDateTime>
-#include <QRegExp>
-#include <QByteArray>
-#include <QList>
 #include <QApplication>
+#include <QByteArray>
+#include <QDateTime>
 #include <QDebug>
+#include <QList>
+#include <QRegExp>
+#include <QRegularExpression>
+#include <QRegularExpressionMatch>
+#include <QTextCodec>
+#include <QUuid>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -89,6 +93,9 @@ OfxAppVersion::OfxAppVersion(KComboBox* combo, KLineEdit* versionEdit, const QSt
     // the swiss army knife entry :)
     m_appMap[i18n("Quicken Windows (Expert)")] = "QWIN:";
 
+    // Quicken (Mac)
+    m_appMap[i18n("Quicken Mac (Expert)")] = "QMOFX:";
+
     // MS-Money
     m_appMap[i18n("MS-Money 2003")] = "Money:1100";
     m_appMap[i18n("MS-Money 2004")] = "Money:1200";
@@ -114,11 +121,12 @@ OfxAppVersion::OfxAppVersion(KComboBox* combo, KLineEdit* versionEdit, const QSt
     }
 
     // not found, check if we have a manual version of this product
-    QRegExp appExp("(\\w+:)(\\d+)");
+    QRegularExpression appExp("(\\w+:)(\\d+|\\w+)");
+    auto matcher = appExp.match(appId);
     if (it_a == m_appMap.constEnd()) {
-        if (appExp.exactMatch(appId)) {
+        if (matcher.hasMatch()) {
             for (it_a = m_appMap.constBegin(); it_a != m_appMap.constEnd(); ++it_a) {
-                if (*it_a == appExp.cap(1))
+                if (*it_a == matcher.captured(1))
                     break;
             }
         }
@@ -130,7 +138,7 @@ OfxAppVersion::OfxAppVersion(KComboBox* combo, KLineEdit* versionEdit, const QSt
         if ((*it_a).endsWith(':')) {
             if (versionEdit) {
                 versionEdit->show();
-                versionEdit->setText(appExp.cap(2));
+                versionEdit->setText(matcher.captured(2));
             } else {
                 combo->setCurrentItem(i18n("Quicken Windows 2008"));
             }
@@ -233,6 +241,10 @@ QString MyMoneyOfxConnector::url() const
 {
     return m_fiSettings.value("url");
 }
+QString MyMoneyOfxConnector::userAgent() const
+{
+    return m_fiSettings.value(QLatin1String("kmmofx-useragent"));
+}
 
 QDate MyMoneyOfxConnector::statementStartDate() const
 {
@@ -339,7 +351,7 @@ void MyMoneyOfxConnector::initRequest(OfxFiLogin* fi) const
     }
 }
 
-const QByteArray MyMoneyOfxConnector::statementRequest() const
+QString MyMoneyOfxConnector::statementRequest() const
 {
     OfxFiLogin fi;
     initRequest(&fi);
@@ -354,20 +366,30 @@ const QByteArray MyMoneyOfxConnector::statementRequest() const
     strncpy(account.account_number, accountnum().toLatin1(), OFX_ACCTID_LENGTH - 1);
     account.account_type = accounttype();
 
-    QByteArray result;
+    QString result;
     if (fi.userpass[0]) {
         char *szrequest = libofx_request_statement(&fi, &account, QDateTime(statementStartDate()).toTime_t());
-        QString request = szrequest;
-        // remove the trailing zero
-        result = request.toUtf8();
-        if(result.at(result.size()-1) == 0)
-            result.truncate(result.size() - 1);
+        auto codec = QTextCodec::codecForName("Windows-1251");
+        result = codec->toUnicode(szrequest);
         free(szrequest);
+        // remove the trailing zero
+        result.remove(QChar(0));
     }
 
     return result;
 }
 
+void MyMoneyOfxConnector::institutionSpecificRequestAdjustment(QString& request)
+{
+    if (request.contains(QLatin1String("<FID>67811")) || request.contains(QLatin1String("<FID>00000"))) {
+        // USAA requires some specific settings
+        // and we do the same with our test account
+        request.replace(QRegularExpression("NEWFILEUID:[\\d\\.]+"), QLatin1String("NEWFILEUID:NONE"));
+        request.replace(QRegularExpression("<TRNUID>[\\d\\.]+"),
+                        QStringLiteral("<TRNUID>%1").arg(QUuid::createUuid().toString(QUuid::WithoutBraces).toUpper()));
+        request.replace(QRegularExpression("<DTACCTUP>19700101"), QLatin1String("<DTACCTUP>19900101"));
+    }
+}
 
 #if 0
 
