@@ -15,10 +15,8 @@
 #include <QRadioButton>
 #include <QSpinBox>
 #include <QByteArray>
-#ifdef IS_APPIMAGE
 #include <QCoreApplication>
 #include <QStandardPaths>
-#endif
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -35,19 +33,20 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
-#include <libofx/libofx.h>
-#include "konlinebankingstatus.h"
-#include "konlinebankingsetupwizard.h"
+#include "importinterface.h"
+#include "kmymoneyutils.h"
 #include "kofxdirectconnectdlg.h"
+#include "konlinebankingsetupwizard.h"
+#include "konlinebankingstatus.h"
 #include "mymoneyaccount.h"
 #include "mymoneyexception.h"
 #include "mymoneystatement.h"
 #include "mymoneystatementreader.h"
+#include "mymoneyutils.h"
 #include "statementinterface.h"
-#include "importinterface.h"
-#include "viewinterface.h"
 #include "ui_importoption.h"
-#include "kmymoneyutils.h"
+#include "viewinterface.h"
+#include <libofx/libofx.h>
 
 //#define DEBUG_LIBOFX
 
@@ -126,15 +125,16 @@ OFXImporter::OFXImporter(QObject *parent, const QVariantList &args) :
     const auto rcFileName = QLatin1String("ofximporter.rc");
     setComponentName(componentName, i18n("OFX Importer"));
 
-#ifdef IS_APPIMAGE
-    const QString rcFilePath = QString("%1/../share/kxmlgui5/%2/%3").arg(QCoreApplication::applicationDirPath(), componentName, rcFileName);
-    setXMLFile(rcFilePath);
+    if (MyMoneyUtils::isRunningAsAppImage()) {
+        const QString rcFilePath = QString("%1/../share/kxmlgui5/%2/%3").arg(QCoreApplication::applicationDirPath(), componentName, rcFileName);
+        setXMLFile(rcFilePath);
 
-    const QString localRcFilePath = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).first() + QLatin1Char('/') + componentName + QLatin1Char('/') + rcFileName;
-    setLocalXMLFile(localRcFilePath);
-#else
-    setXMLFile(rcFileName);
-#endif
+        const QString localRcFilePath =
+            QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).first() + QLatin1Char('/') + componentName + QLatin1Char('/') + rcFileName;
+        setLocalXMLFile(localRcFilePath);
+    } else {
+        setXMLFile(rcFileName);
+    }
 
     createActions();
 
@@ -246,11 +246,22 @@ bool OFXImporter::import(const QString& filename)
 
     QByteArray filename_deep = QFile::encodeName(filename);
 
+#ifndef Q_OS_WIN
+
+    // setting the global variables in the windows version
+    // created on binary-factory.kde.org causes the following
+    // assignment statements to create an access violation exception
+    // which crashes the application. So we avoid setting
+    // them at all under Windows.
     ofx_STATUS_msg = true;
     ofx_INFO_msg  = true;
     ofx_WARNING_msg = true;
     ofx_ERROR_msg = true;
 
+    // Don't show the position that caused a message to be shown
+    // This has no setter (see libofx.h)
+    ofx_show_position = false;
+
 #ifdef DEBUG_LIBOFX
     ofx_PARSER_msg = true;
     ofx_DEBUG_msg = true;
@@ -259,15 +270,12 @@ bool OFXImporter::import(const QString& filename)
     ofx_DEBUG3_msg = true;
     ofx_DEBUG4_msg = true;
     ofx_DEBUG5_msg = true;
+#endif
 #endif
 
     LibofxContextPtr ctx = libofx_get_new_context();
     Q_CHECK_PTR(ctx);
 
-    // Don't show the position that caused a message to be shown
-    // This has no setter (see libofx.h)
-    ofx_show_position = false;
-
     d->m_hashes.clear();
 
     qDebug("setup callback routines");
@@ -278,12 +286,12 @@ bool OFXImporter::import(const QString& filename)
     ofx_set_status_cb(ctx, ofxStatusCallback, this);
     qDebug("process data");
 
-#ifdef IS_APPIMAGE
+#ifdef Q_OS_LINUX
     // libofx needs to know where to pick up the DTD
     // files when running in APPIMAGE mode
-    const char* env = getenv("APPDIR");
-    if (env && *env) {
-        QByteArray dir = env;
+    const auto env = qgetenv("APPDIR");
+    if (!env.isEmpty()) {
+        QByteArray dir(env);
         dir.append("/usr/share/libofx/dtd/");
         qDebug() << "Set DTD dir to" << dir;
         libofx_set_dtd_dir(ctx, dir.data());
@@ -639,7 +647,12 @@ int OFXImporter::ofxStatementCallback(struct OfxStatementData data, void* pv)
         s.m_strCurrency = QString::fromUtf8(data.currency);
     }
     if (data.account_id_valid) {
-        s.m_strAccountNumber = QString::fromUtf8(data.account_id);
+        // only use the account_id if it is filled with non-blank data
+        // see https://bugs.kde.org/show_bug.cgi?id=428156
+        const auto account_id = QString::fromUtf8(data.account_id).trimmed();
+        if (!account_id.isEmpty()) {
+            s.m_strAccountNumber = account_id;
+        }
     }
 
     if (data.date_start_valid) {
@@ -680,8 +693,26 @@ int OFXImporter::ofxAccountCallback(struct OfxAccountData data, void * pv)
     pofx->d->m_hashes.clear();
 
     if (data.account_id_valid) {
-        s.m_strAccountName = QString::fromUtf8(data.account_name);
-        s.m_strAccountNumber = QString::fromUtf8(data.account_id);
+        const auto account_name = QString::fromUtf8(data.account_name);
+        // in case libofx does not extract any value, it returns
+        // one of the following fixed strings in this member.
+        // See OfxAccountContainer::gen_account_id in
+        // libofx/lib/ofx_container_account.cpp for details
+        static const QStringList emptyEntries({
+            "Credit card ",
+            "Investment account at broker ",
+            "Bank account ",
+        });
+        if (!emptyEntries.contains(account_name)) {
+            s.m_strAccountName = account_name.trimmed();
+        }
+
+        // only use the account_id if it is filled with non-blank data
+        // see https://bugs.kde.org/show_bug.cgi?id=428156
+        const auto account_id = QString::fromUtf8(data.account_id).trimmed();
+        if (!account_id.isEmpty()) {
+            s.m_strAccountNumber = account_id;
+        }
     }
     if (data.bank_id_valid) {
         s.m_strRoutingNumber = QString::fromUtf8(data.bank_id);
@@ -881,6 +912,10 @@ MyMoneyKeyValueContainer OFXImporter::onlineBankingSettings(const MyMoneyKeyValu
         } else {
             kvp.deletePair(QStringLiteral("kmmofx-fixbuysellsignage"));
         }
+        if (!d->m_statusDlg->m_userAgentEdit->text().isEmpty())
+            kvp.setValue(QStringLiteral("kmmofx-useragent"), d->m_statusDlg->m_userAgentEdit->text());
+        else
+            kvp.deletePair(QStringLiteral("kmmofx-useragent"));
         // get rid of pre 4.6 values
         kvp.deletePair(QStringLiteral("kmmofx-preferPayeeid"));
     }
