@@ -9,10 +9,8 @@
 
 // ----------------------------------------------------------------------------
 // QT Includes
-#ifdef IS_APPIMAGE
 #include <QCoreApplication>
 #include <QStandardPaths>
-#endif
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -25,8 +23,8 @@
 // Project Includes
 
 #include "kexportdlg.h"
-
 #include "mymoneyqifwriter.h"
+#include "mymoneyutils.h"
 #include "viewinterface.h"
 
 QIFExporter::QIFExporter(QObject *parent, const QVariantList &args) :
@@ -37,15 +35,16 @@ QIFExporter::QIFExporter(QObject *parent, const QVariantList &args) :
     const auto rcFileName = QLatin1String("qifexporter.rc");
     setComponentName(componentName, i18n("QIF exporter"));
 
-#ifdef IS_APPIMAGE
-    const QString rcFilePath = QString("%1/../share/kxmlgui5/%2/%3").arg(QCoreApplication::applicationDirPath(), componentName, rcFileName);
-    setXMLFile(rcFilePath);
+    if (MyMoneyUtils::isRunningAsAppImage()) {
+        const QString rcFilePath = QString("%1/../share/kxmlgui5/%2/%3").arg(QCoreApplication::applicationDirPath(), componentName, rcFileName);
+        setXMLFile(rcFilePath);
 
-    const QString localRcFilePath = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).first() + QLatin1Char('/') + componentName + QLatin1Char('/') + rcFileName;
-    setLocalXMLFile(localRcFilePath);
-#else
-    setXMLFile(rcFileName);
-#endif
+        const QString localRcFilePath =
+            QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation).first() + QLatin1Char('/') + componentName + QLatin1Char('/') + rcFileName;
+        setLocalXMLFile(localRcFilePath);
+    } else {
+        setXMLFile(rcFileName);
+    }
 
     createActions();
     // For information, announce that we have been loaded.
