@@ -1,12 +1,12 @@
 //krazy:skip
 /****************************************************************************
 **
-** SPDX-FileCopyrightText: 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** SPDX-FileCopyrightText: 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the QtSql module of the Qt Toolkit.
 **
-SPDX-License-Identifier: LGPL-2.1-only WITH Qt-LGPL-exception-1.1 OR LGPL-3.0-only WITH Qt-LGPL-exception-1.1 OR LicenseRef-Qt-Commercial
+** SPDX-License-Identifier: LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KFQF-Accepted-GPL OR LicenseRef-Qt-Commercial
 **
 ****************************************************************************/
 
@@ -25,7 +25,6 @@ SPDX-License-Identifier: LGPL-2.1-only WITH Qt-LGPL-exception-1.1 OR LGPL-3.0-on
 //
 
 #include <QtSql/qsqldriver.h>
-#include <QtSql/qsqlresult.h>
 
 struct sqlite3;
 
@@ -37,14 +36,14 @@ struct sqlite3;
 
 QT_BEGIN_NAMESPACE
 
+class QSqlResult;
 class QSQLiteDriverPrivate;
-class QSQLiteDriver;
 
 class Q_EXPORT_SQLDRIVER_SQLITE QSQLiteDriver : public QSqlDriver
 {
     Q_DECLARE_PRIVATE(QSQLiteDriver)
     Q_OBJECT
-    friend class QSQLiteResult;
+    friend class QSQLiteResultPrivate;
 public:
     explicit QSQLiteDriver(QObject *parent = 0);
     explicit QSQLiteDriver(sqlite3 *connection, QObject *parent = 0);
@@ -67,6 +66,12 @@ public:
     QSqlIndex primaryIndex(const QString &table) const Q_DECL_OVERRIDE;
     QVariant handle() const Q_DECL_OVERRIDE;
     QString escapeIdentifier(const QString &identifier, IdentifierType) const Q_DECL_OVERRIDE;
+
+    bool subscribeToNotification(const QString &name) Q_DECL_OVERRIDE;
+    bool unsubscribeFromNotification(const QString &name) Q_DECL_OVERRIDE;
+    QStringList subscribedToNotifications() const Q_DECL_OVERRIDE;
+private Q_SLOTS:
+    void handleNotification(const QString &tableName, qint64 rowid);
 };
 
 QT_END_NAMESPACE
