@@ -3,7 +3,7 @@
     SPDX-FileCopyrightText: 2003 Michael Edwardes <mte@users.sourceforge.net>
     SPDX-FileCopyrightText: 2004-2006 Ace Jones <acejones@users.sourceforge.net>
     SPDX-FileCopyrightText: 2004 Kevin Tambascio <ktambascio@users.sourceforge.net>
-    SPDX-FileCopyrightText: 2009-2014 Cristian One ț <onet.cristian@gmail.com>
+    SPDX-FileCopyrightText: 2009-2014 Cristian Oneț <onet.cristian@gmail.com>
     SPDX-FileCopyrightText: 2012 Alessandro Russo <axela74@yahoo.it>
     SPDX-FileCopyrightText: 2016 Christian Dávid <christian-david@web.de>
     SPDX-FileCopyrightText: 2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
@@ -24,7 +24,7 @@ class TestMyMoneyObjectPrivate : public MyMoneyObjectPrivate
 {
 };
 
-class TestMyMoneyObject : public MyMoneyObject
+class TestMyMoneyObject final : public MyMoneyObject
 {
     Q_DECLARE_PRIVATE(TestMyMoneyObject)
 
