@@ -76,7 +76,7 @@ void KInstitutionsView::refresh()
 
     d->m_proxyModel->invalidate();
     d->m_proxyModel->setHideEquityAccounts(!KMyMoneySettings::expertMode());
-    d->m_proxyModel->setHideClosedAccounts(KMyMoneySettings::hideClosedAccounts() && !KMyMoneySettings::showAllAccounts());
+    d->m_proxyModel->setHideClosedAccounts(!KMyMoneySettings::showAllAccounts());
 }
 
 void KInstitutionsView::showEvent(QShowEvent * event)
