@@ -147,6 +147,15 @@ public:
         m_calculator->setFocus();
     }
 
+    void cut()
+    {
+        Q_Q(AmountEdit);
+        // only cut if parts of the text are selected
+        if (q->hasSelectedText() && (q->text() != q->selectedText())) {
+            cut();
+        }
+    }
+
     AmountEdit*           q_ptr;
     QFrame*               m_calculatorFrame;
     KMyMoneyCalculator*   m_calculator;
@@ -212,6 +221,19 @@ void AmountEdit::resizeEvent(QResizeEvent* event)
     d->m_calculatorButton->move(width() - d->m_calculatorButton->width() - frameWidth - 2, 2);
 }
 
+void AmountEdit::focusInEvent(QFocusEvent* event)
+{
+    QLineEdit::focusInEvent(event);
+    if (event->reason() == Qt::MouseFocusReason) {
+        if (!hasSelectedText()) {
+            // we need to wait until all processing is done before
+            // we can successfully call selectAll. Hence the
+            // delayed execution when we return back to the event loop
+            metaObject()->invokeMethod(this, &QLineEdit::selectAll, Qt::QueuedConnection);
+        }
+    }
+}
+
 void AmountEdit::focusOutEvent(QFocusEvent* event)
 {
     Q_D(AmountEdit);
@@ -240,9 +262,7 @@ void AmountEdit::keyPressEvent(QKeyEvent* event)
     switch(event->key()) {
     case Qt::Key_Plus:
     case Qt::Key_Minus:
-        if (hasSelectedText()) {
-            cut();
-        }
+        d->cut();
         if (text().length() == 0) {
             QLineEdit::keyPressEvent(event);
             break;
@@ -256,15 +276,12 @@ void AmountEdit::keyPressEvent(QKeyEvent* event)
                 break;
             }
         }
-    // intentional fall through
+        // intentional fall through
 
     case Qt::Key_Slash:
     case Qt::Key_Asterisk:
     case Qt::Key_Percent:
-        if (hasSelectedText()) {
-            // remove the selected text
-            cut();
-        }
+        d->cut();
         d->calculatorOpen(event);
         break;
 
