@@ -1,20 +1,8 @@
 /*
- * Copyright 2006-2018  Thomas Baumgart <tbaumgart@kde.org>
- * Copyright 2017-2018  Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2006-2018 Thomas Baumgart <tbaumgart@kde.org>
+    SPDX-FileCopyrightText: 2017-2018 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "groupmarkers.h"
 
@@ -49,35 +37,35 @@ using namespace eMyMoney;
 
 namespace KMyMoneyRegister
 {
-  class TypeGroupMarkerPrivate : public GroupMarkerPrivate
-  {
-  public:
+class TypeGroupMarkerPrivate : public GroupMarkerPrivate
+{
+public:
     eRegister::CashFlowDirection m_dir;
-  };
+};
 }
 
 TypeGroupMarker::TypeGroupMarker(KMyMoneyRegister::Register* parent, eRegister::CashFlowDirection dir, Account::Type accType) :
     GroupMarker(*new TypeGroupMarkerPrivate, parent, QString())
 {
-  Q_D(TypeGroupMarker);
-  d->m_dir = dir;
-  switch (dir) {
+    Q_D(TypeGroupMarker);
+    d->m_dir = dir;
+    switch (dir) {
     case eRegister::CashFlowDirection::Deposit:
-      d->m_txt = i18nc("Deposits onto account", "Deposits");
-      if (accType == Account::Type::CreditCard) {
-        d->m_txt = i18nc("Payments towards credit card", "Payments");
-      }
-      break;
+        d->m_txt = i18nc("Deposits onto account", "Deposits");
+        if (accType == Account::Type::CreditCard) {
+            d->m_txt = i18nc("Payments towards credit card", "Payments");
+        }
+        break;
     case eRegister::CashFlowDirection::Payment:
-      d->m_txt = i18nc("Payments made from account", "Payments");
-      if (accType == Account::Type::CreditCard) {
-        d->m_txt = i18nc("Payments made with credit card", "Charges");
-      }
-      break;
+        d->m_txt = i18nc("Payments made from account", "Payments");
+        if (accType == Account::Type::CreditCard) {
+            d->m_txt = i18nc("Payments made with credit card", "Charges");
+        }
+        break;
     default:
-      qDebug("Unknown CashFlowDirection %d for TypeGroupMarker constructor", (int)dir);
-      break;
-  }
+        qDebug("Unknown CashFlowDirection %d for TypeGroupMarker constructor", (int)dir);
+        break;
+    }
 }
 
 TypeGroupMarker::~TypeGroupMarker()
@@ -86,8 +74,8 @@ TypeGroupMarker::~TypeGroupMarker()
 
 eRegister::CashFlowDirection TypeGroupMarker::sortType() const
 {
-  Q_D(const TypeGroupMarker);
-  return d->m_dir;
+    Q_D(const TypeGroupMarker);
+    return d->m_dir;
 }
 
 PayeeGroupMarker::PayeeGroupMarker(KMyMoneyRegister::Register* parent, const QString& name) :
@@ -101,8 +89,8 @@ PayeeGroupMarker::~PayeeGroupMarker()
 
 const QString& PayeeGroupMarker::sortPayee() const
 {
-  Q_D(const GroupMarker);
-  return d->m_txt;
+    Q_D(const GroupMarker);
+    return d->m_txt;
 }
 
 CategoryGroupMarker::CategoryGroupMarker(KMyMoneyRegister::Register* parent, const QString& category) :
@@ -116,51 +104,51 @@ CategoryGroupMarker::~CategoryGroupMarker()
 
 const QString& CategoryGroupMarker::sortCategory() const
 {
-  Q_D(const GroupMarker);
-  return d->m_txt;
+    Q_D(const GroupMarker);
+    return d->m_txt;
 }
 const QString CategoryGroupMarker::sortSecurity() const
 {
-  Q_D(const GroupMarker);
-  return d->m_txt;
+    Q_D(const GroupMarker);
+    return d->m_txt;
 }
 
 const char* CategoryGroupMarker::className()
 {
-  return "CategoryGroupMarker";
+    return "CategoryGroupMarker";
 }
 
 namespace KMyMoneyRegister
 {
-  class ReconcileGroupMarkerPrivate : public GroupMarkerPrivate
-  {
-  public:
+class ReconcileGroupMarkerPrivate : public GroupMarkerPrivate
+{
+public:
     eMyMoney::Split::State m_state;
-  };
+};
 }
 
 ReconcileGroupMarker::ReconcileGroupMarker(KMyMoneyRegister::Register* parent, eMyMoney::Split::State state) :
     GroupMarker(*new ReconcileGroupMarkerPrivate, parent, QString())
 {
-  Q_D(ReconcileGroupMarker);
-  d->m_state = state;
-  switch (state) {
+    Q_D(ReconcileGroupMarker);
+    d->m_state = state;
+    switch (state) {
     case eMyMoney::Split::State::NotReconciled:
-      d->m_txt = i18nc("Reconcile state 'Not reconciled'", "Not reconciled");
-      break;
+        d->m_txt = i18nc("Reconcile state 'Not reconciled'", "Not reconciled");
+        break;
     case eMyMoney::Split::State::Cleared:
-      d->m_txt = i18nc("Reconcile state 'Cleared'", "Cleared");
-      break;
+        d->m_txt = i18nc("Reconcile state 'Cleared'", "Cleared");
+        break;
     case eMyMoney::Split::State::Reconciled:
-      d->m_txt = i18nc("Reconcile state 'Reconciled'", "Reconciled");
-      break;
+        d->m_txt = i18nc("Reconcile state 'Reconciled'", "Reconciled");
+        break;
     case eMyMoney::Split::State::Frozen:
-      d->m_txt = i18nc("Reconcile state 'Frozen'", "Frozen");
-      break;
+        d->m_txt = i18nc("Reconcile state 'Frozen'", "Frozen");
+        break;
     default:
-      d->m_txt = i18nc("Unknown reconcile state", "Unknown");
-      break;
-  }
+        d->m_txt = i18nc("Unknown reconcile state", "Unknown");
+        break;
+    }
 }
 
 ReconcileGroupMarker::~ReconcileGroupMarker()
@@ -169,36 +157,35 @@ ReconcileGroupMarker::~ReconcileGroupMarker()
 
 eMyMoney::Split::State ReconcileGroupMarker::sortReconcileState() const
 {
-  Q_D(const ReconcileGroupMarker);
-  return d->m_state;
+    Q_D(const ReconcileGroupMarker);
+    return d->m_state;
 }
 
 namespace KMyMoneyRegister
 {
-  class RegisterPrivate
-  {
-  public:
+class RegisterPrivate
+{
+public:
     RegisterPrivate() :
-      m_selectAnchor(nullptr),
-      m_focusItem(nullptr),
-      m_ensureVisibleItem(nullptr),
-      m_firstItem(nullptr),
-      m_lastItem(nullptr),
-      m_firstErroneous(nullptr),
-      m_lastErroneous(nullptr),
-      m_markErroneousTransactions(0),
-      m_rowHeightHint(0),
-      m_ledgerLensForced(false),
-      m_selectionMode(QTableWidget::MultiSelection),
-      m_needResize(true),
-      m_listsDirty(false),
-      m_ignoreNextButtonRelease(false),
-      m_needInitialColumnResize(false),
-      m_usedWithEditor(false),
-      m_mouseButton(Qt::MouseButtons(Qt::NoButton)),
-      m_modifiers(Qt::KeyboardModifiers(Qt::NoModifier)),
-      m_lastCol(eTransaction::Column::Account),
-      m_detailsColumnType(eRegister::DetailColumn::PayeeFirst)
+        m_selectAnchor(nullptr),
+        m_focusItem(nullptr),
+        m_ensureVisibleItem(nullptr),
+        m_firstItem(nullptr),
+        m_lastItem(nullptr),
+        m_firstErroneous(nullptr),
+        m_lastErroneous(nullptr),
+        m_rowHeightHint(0),
+        m_ledgerLensForced(false),
+        m_selectionMode(QTableWidget::MultiSelection),
+        m_needResize(true),
+        m_listsDirty(false),
+        m_ignoreNextButtonRelease(false),
+        m_needInitialColumnResize(false),
+        m_usedWithEditor(false),
+        m_mouseButton(Qt::MouseButtons(Qt::NoButton)),
+        m_modifiers(Qt::KeyboardModifiers(Qt::NoModifier)),
+        m_lastCol(eTransaction::Column::Account),
+        m_detailsColumnType(eRegister::DetailColumn::PayeeFirst)
     {
     }
 
@@ -216,7 +203,6 @@ namespace KMyMoneyRegister
     RegisterItem*                m_firstErroneous;
     RegisterItem*                m_lastErroneous;
 
-    int                          m_markErroneousTransactions;
     int                          m_rowHeightHint;
 
     MyMoneyAccount               m_account;
@@ -236,5 +222,5 @@ namespace KMyMoneyRegister
     QRect                        m_lastRepaintRect;
     eRegister::DetailColumn            m_detailsColumnType;
 
-  };
+};
 }
